@@ -518,18 +518,19 @@ class _Confirm:
     CONFIRM = True
 
 
-class _Maintenance:
-    _LOCK = threading.Lock()
+MAINTENANCE_LOCK = threading.Lock()
 
+
+class _Maintenance:
     def run(self):
         from mini_buildd import daemon
 
-        if self._LOCK.acquire(blocking=False):  # pylint: disable=consider-using-with
+        if MAINTENANCE_LOCK.acquire(blocking=False):  # pylint: disable=consider-using-with
             try:
                 with daemon.Stopped():
                     self._run()
             finally:
-                self._LOCK.release()
+                MAINTENANCE_LOCK.release()
         else:
             raise util.HTTPUnavailable("Another maintenance API call currently running")
 
