@@ -10,8 +10,8 @@ import hashlib
 
 import django.utils
 import django
-import mini_buildd
-import mini_buildd.api
+
+from mini_buildd import config, util, dist, api
 
 
 LOG = logging.getLogger(__name__)
@@ -20,9 +20,7 @@ register = django.template.Library()
 
 
 class Css():
-    """
-    Mappings: Internal status strings to CSS class from ``mini_buildd.css``.
-    """
+    """Mappings: Internal status strings to CSS class from ``mini_buildd.css``"""
 
     ERROR = "mbd-error"
     WARNING = "mbd-warning"
@@ -66,6 +64,13 @@ class Css():
             "Prepared": NOTICE,  # Prepared StatusModel object
             "Active": SUCCESS,   # Active StatusModel object
         },
+        # For API call setup (slightly differs from model_status)
+        "setup_status": {
+            "missing": ERROR,        # Non-existing object
+            "exists": INFO,          # Existing (non StatusModel) object
+            "active": SUCCESS,       # Active StatusModel object
+            "deactivated": WARNING,  # Non-active StatusModel object
+        },
         "django_messages": {
             "debug": INFO,
             "info": INFO,
@@ -83,13 +88,13 @@ def mbd_cssmap(kind, key):
 
 @register.simple_tag
 def mbd_get(obj):
-    """Identity function. Handy to set variables in templates (``{% mbd_get some_value as myvar %}``)."""
+    """Identity function. Handy to set variables in templates (``{% mbd_get some_value as myvar %}``)"""
     return obj
 
 
 @register.simple_tag
 def mbd_dict_get(dict_, key):
-    """Get value from dict even if the key has a special name (like hyphens in a changes file field), or is in another variable."""
+    """Get value from dict even if the key has a special name (like hyphens in a changes file field), or is in another variable"""
     return dict_.get(key)
 
 
@@ -101,7 +106,7 @@ def mbd_fromtimestamp(stamp):
 @register.filter
 def mbd_parent(path):
     """
-    Get parent path (uri), always w/ trailing slash.
+    Get parent path (uri), always w/ trailing slash
 
     >>> mbd_parent("/parent/file")
     '/parent/'
@@ -125,8 +130,8 @@ def mbd_join(path, *paths):
 
 @register.filter
 def mbd_jsonpp(obj):
-    """Get pretty print from json-serializable object."""
-    return mini_buildd.misc.json_pretty(obj)
+    """Get pretty print from json-serializable object"""
+    return util.json_pretty(obj)
 
 
 @register.simple_tag
@@ -136,23 +141,23 @@ def mbd_token():
 
 @register.simple_tag
 def mbd_hash(data):
-    return f"mbd-hash-{hashlib.sha224(bytes(data, encoding=mini_buildd.config.CHAR_ENCODING)).hexdigest()}"
+    return f"mbd-hash-{hashlib.sha224(bytes(data, encoding=config.CHAR_ENCODING)).hexdigest()}"
 
 
 @register.filter
 def mbd_codename(diststr):
-    """Get codename from diststr. On any error, just return empty string."""
+    """Get codename from diststr. On any error, just return empty string"""
     try:
-        return mini_buildd.dist.Dist(diststr).codename
+        return dist.Dist(diststr).codename
     except Exception:
         return ""
 
 
 @register.filter
 def mbd_repository(diststr):
-    """Get repository from diststr. On any error, just return empty string."""
+    """Get repository from diststr. On any error, just return empty string"""
     try:
-        return mini_buildd.dist.Dist(diststr).repository
+        return dist.Dist(diststr).repository
     except Exception:
         return ""
 
@@ -160,8 +165,7 @@ def mbd_repository(diststr):
 @register.simple_tag
 def mbd_model_stats(model):
     ret = {}
-    mdl, _sep, cls = model.partition(".")  # model="daemon.Daemon" (see admin.py)
-    model_class = getattr(getattr(mini_buildd.mdls(), mdl), cls)
+    model_class = getattr(util.models(), model)
     if getattr(model_class, "mbd_is_prepared", None):
         # Status model
         ret["active"] = model_class.objects.filter(status__exact=model_class.STATUS_ACTIVE).count()
@@ -193,9 +197,9 @@ def mbd_api(context, call, name=None, hide_options=False, verbose=False, **kwarg
     prefix = "value_"
     api_args = {k[len(prefix):]: v for k, v in kwargs.items() if k.startswith(prefix)}
     if isinstance(call, str):
-        api_cls = mini_buildd.api.CALLS.get(call)
+        api_cls = api.CALLS.get(call)
         if api_cls is None:
-            raise mini_buildd.HTTPBadRequest(f"Unknown API call: {name}")
+            raise util.HTTPBadRequest(f"Unknown API call: {call}")
         api_call = api_cls(**api_args)
     else:
         api_call = call
@@ -204,7 +208,7 @@ def mbd_api(context, call, name=None, hide_options=False, verbose=False, **kwarg
     args = {"mandatory": [], "optional": [], "hidden": []}
     for arg in api_call.args.values():
         args["mandatory" if arg.needs_value() else "hidden" if hide_options else "optional"].append(arg)
-    args["optional" if args["optional"] else "hidden"].append(mini_buildd.api.Output())
+    args["optional" if args["optional"] else "hidden"].append(api.Output())
 
     return {
         "request": context.get("request"),
@@ -259,7 +263,7 @@ class PlainFilter(dict):
     BUILDLOG_INDEX_REGEXES = [
         (re.compile(r"\| (.*) \|"), 1, "mbd-info"),                                            # sbuild section headers
         (re.compile(r"^MINI_BUILDD: .+"), 0, "mbd-info"),                                      # mini-buildd banners (see files.py)
-        # (re.compile(rf"^/.+/{mini_buildd.sbuild.SETUP_D_DIR}/(.+_.+)"), 1, "mbd-info"),      # .. attention:: mini-buildd setup scripts -- alternative to the banner approach above (maybe nicer if we can also drop banner support)
+        # (re.compile(rf"^/.+/{sbuild.SETUP_D_DIR}/(.+_.+)"), 1, "mbd-info"),      # .. attention:: mini-buildd setup scripts -- alternative to the banner approach above (maybe nicer if we can also drop banner support)
         (re.compile(r".*make.*\*\*\*.*"), 0, "mbd-error"),                                     # make fatal error
         (re.compile(r"(^W(ARNING)?: .+)|(^W(ARN)?: .+)", re.IGNORECASE), 0, "mbd-warning"),    # warnings (lintian, others)
         (re.compile(r"(^E(RROR)?: .+)|(^E(RR)?: .+)", re.IGNORECASE), 0, "mbd-error"),         # errors (lintian, others)
@@ -274,7 +278,7 @@ class PlainFilter(dict):
     ]
 
     def regex_filter(self, file_path, regexes):
-        with open(file_path, "r", encoding=mini_buildd.config.CHAR_ENCODING, errors="ignore") as f:
+        with open(file_path, "r", encoding=config.CHAR_ENCODING, errors="ignore") as f:
             log = ""
             for line in f:
                 for m in regexes:
@@ -296,12 +300,12 @@ class PlainFilter(dict):
 
     @classmethod
     def filter_json(cls, file_path):
-        with mini_buildd.fopen(file_path) as f:
-            return mini_buildd.misc.json_pretty(json.load(f))
+        with util.fopen(file_path) as f:
+            return util.json_pretty(json.load(f))
 
     @classmethod
     def filter_default(cls, file_path):
-        with mini_buildd.fopen(file_path, "r", errors="ignore") as f:
+        with util.fopen(file_path, "r", errors="ignore") as f:
             return f.read()
 
     def __init__(self, content, file_path, uri, title):
