@@ -4,8 +4,7 @@ import sys
 import socket
 import re
 
-import mini_buildd
-import mini_buildd.files
+from mini_buildd import util, files
 
 #: This should never ever be changed
 CHAR_ENCODING = "UTF-8"
@@ -47,7 +46,7 @@ class Auth():
         return self.auth.name
 
     def is_authorized(self, user):
-        """Check if django user is authorized."""
+        """Check if django user is authorized"""
         def active_login():
             return user.is_authenticated and user.is_active
 
@@ -72,7 +71,7 @@ AUTH_ADMIN = Auth(AuthType.ADMIN)
 
 
 class Uri:
-    """URI string with some convenience functionality."""
+    """URI string with some convenience functionality"""
 
     DJANGO_PATH_REGEX = r"(?:(?P<path>.*))?"
 
@@ -110,7 +109,7 @@ class Uri:
         return os.path.join(prefix, self.uri, *args)
 
     def url_join(self, *args, endpoint=None):
-        ep = mini_buildd.http_endpoint() if endpoint is None else endpoint
+        ep = util.http_endpoint() if endpoint is None else endpoint
         return ep.geturl(path=self.join(*args))
 
     @classmethod
@@ -189,12 +188,12 @@ URIS = {
     },
 }
 
-MAIN_MENU_LEFT = ["events", "builds", "repositories", "|", "manual", "api"]
-MAIN_MENU_RIGHT = ["builders", "crontab", "log", "|", "setup"]
+MAIN_MENU_LEFT = ["events", "builds", "repositories", "builders", "|", "manual", "api"]
+MAIN_MENU_RIGHT = ["setup", "crontab", "log", "|"]
 
 
 class Route:
-    """Link a path (may be None, may be run-time) to uris (may be empty)."""
+    """Link a path (may be None, may be run-time) to uris (may be empty)"""
 
     def __init__(self, path=None, uris=None):
         self.path = path
@@ -216,31 +215,31 @@ class Routes(dict):
         def homepth(path):
             return os.path.join(self.home, path)
 
-        self._add("home", mini_buildd.files.Path(self.home))
-        self._add("etc", mini_buildd.files.Path(homepth("etc"), create=True))
+        self._add("home", files.Path(self.home))
+        self._add("etc", files.Path(homepth("etc"), create=True))
         self._add("setup", None)
-        self._add("static", mini_buildd.files.Path(f"{PY_PACKAGE_PATH}/mini_buildd/static"))
+        self._add("static", files.Path(f"{PY_PACKAGE_PATH}/mini_buildd/static"))
 
         # 'var/shared': Shared with chroots
-        self._add("builds", mini_buildd.files.Path(homepth("var/shared/builds"), create=True))   # Build directory
-        self._add("libdir", mini_buildd.files.Path(homepth("var/shared/libdir"), create=True))   # Shared libdir: Can optionally be used for persistent shared data (like ccache)
+        self._add("builds", files.Path(homepth("var/shared/builds"), create=True))   # Build directory
+        self._add("libdir", files.Path(homepth("var/shared/libdir"), create=True))   # Shared libdir: Can optionally be used for persistent shared data (like ccache)
 
-        self._add("events", mini_buildd.files.Path(homepth("var/events"), create=True))
-        self._add("event_hooks", mini_buildd.files.Path(homepth("etc/event-hooks"), create=True))
+        self._add("events", files.Path(homepth("var/events"), create=True))
+        self._add("event_hooks", files.Path(homepth("etc/event-hooks"), create=True))
 
-        self._add("repositories", mini_buildd.files.Path(homepth("repositories"), create=True))
-        self._add("chroots", mini_buildd.files.Path(homepth("var/chroots"), create=True))
+        self._add("repositories", files.Path(homepth("repositories"), create=True))
+        self._add("chroots", files.Path(homepth("var/chroots"), create=True))
         self._add("builders", None)
-        self._add("crontab", mini_buildd.files.Path(homepth("var/crontab"), create=True))
+        self._add("crontab", files.Path(homepth("var/crontab"), create=True))
         self._add("sitemap", None)
         self._add("api", None)
 
-        self._add("log", mini_buildd.files.Path(homepth("var/log"), create=True))
+        self._add("log", files.Path(homepth("var/log"), create=True))
 
-        self._add("tmp", mini_buildd.files.Path(homepth("var/tmp"), create=True))
-        self._add("incoming", mini_buildd.files.Path(homepth("incoming"), create=True))
+        self._add("tmp", files.Path(homepth("var/tmp"), create=True))
+        self._add("incoming", files.Path(homepth("incoming"), create=True))
 
-        self._add("manual", mini_buildd.files.Path(os.path.realpath("/usr/share/doc/mini-buildd/html")))
+        self._add("manual", files.Path(os.path.realpath("/usr/share/doc/mini-buildd/html")))
 
 
 #: Variable items (see mini-buildd main script)
@@ -253,9 +252,9 @@ ROUTES = {}
 
 
 def default_ftp_endpoint():
-    """Compute default ftp endpoint string from main http endpoint."""
-    port = mini_buildd.http_endpoint().options.get("port")
-    return mini_buildd.http_endpoint().description.replace(f"port={port}", f"port={int(port)+1}")
+    """Compute default ftp endpoint string from main http endpoint"""
+    port = util.http_endpoint().options.get("port")
+    return util.http_endpoint().description.replace(f"port={port}", f"port={int(port)+1}")
 
 
 def default_identity():
