@@ -9,7 +9,7 @@ import calendar
 import sched
 import threading
 
-import mini_buildd.threads
+from mini_buildd import config, util, threads, models
 
 LOG = logging.getLogger(__name__)
 
@@ -21,30 +21,35 @@ def _rdate(base_date, h_start, h_stop):
 
 
 def next_yearly_run():
-    """First day of next month between 0am and 1am."""
+    """First day of next month between 0am and 1am"""
     today = datetime.date.today()
     return _rdate(datetime.datetime(year=today.year + 1, month=1, day=1), 0, 6)
 
 
 def next_monthly_run():
-    """First day of next month between 0am and 1am."""
+    """First day of next month between 0am and 1am"""
     today = datetime.date.today()
     return _rdate(today.replace(day=1) + datetime.timedelta(calendar.monthrange(today.year, today.month)[1]), 0, 1)
 
 
 def next_weekly_run():
-    """Next sunday between 2am and 3am."""
+    """Next sunday between 2am and 3am"""
     now = datetime.datetime.now()
     return _rdate(now + datetime.timedelta(days=7 - (now.isoweekday() % 7)), 2, 3)
 
 
 def next_daily_run():
-    """Next day between 4am and 6am."""
+    """Next day between 4am and 6am"""
     return _rdate(datetime.datetime.now() + datetime.timedelta(days=1), 4, 6)
 
 
+def next_hourly_run():
+    """Run every hour"""
+    return datetime.datetime.now() + datetime.timedelta(hours=1)
+
+
 def next_minutely_run():
-    """For testing only; start in one minute."""
+    """For testing only; start in one minute"""
     return datetime.datetime.now() + datetime.timedelta(minutes=1)
 
 
@@ -53,6 +58,7 @@ class Type(enum.Enum):
     MONTHLY = enum.auto()
     WEEKLY = enum.auto()
     DAILY = enum.auto()
+    HOURLY = enum.auto()
     MINUTELY = enum.auto()
 
 
@@ -60,6 +66,7 @@ NEXT_RUN = {Type.YEARLY: next_yearly_run,
             Type.MONTHLY: next_monthly_run,
             Type.WEEKLY: next_weekly_run,
             Type.DAILY: next_daily_run,
+            Type.HOURLY: next_hourly_run,
             Type.MINUTELY: next_minutely_run}
 
 
@@ -68,7 +75,7 @@ class _Job():
         self.next_run = NEXT_RUN[self.type]()
         self.next_run_utc = self.next_run.astimezone(tz=datetime.timezone.utc)
         self.event = self.scheduler.enter((self.next_run - datetime.datetime.now()).total_seconds(), 1, self.__action, argument=self._argument, kwargs=self._kwargs)
-        LOG.info(f"Scheduling cronjob '{self.desc}' for {self.next_run} (LOCAL), {self.next_run_utc} (UTC)")
+        LOG.debug(f"Scheduling cronjob '{self.desc}' for {self.next_run} (LOCAL), {self.next_run_utc} (UTC)")
 
     def __init__(self, scheduler, type_, action, argument=None, kwargs=None):
         self.scheduler = scheduler
@@ -80,7 +87,7 @@ class _Job():
 
         self.name = action.__name__
         self.desc = inspect.getdoc(self._action)
-        self.logfile = mini_buildd.config.ROUTES["crontab"].path.join(f"{self.type.name}_{self.name}.log")
+        self.logfile = config.ROUTES["crontab"].path.join(f"{self.type.name}_{self.name}.log")
         self.log = collections.deque(self.readlog(), maxlen=20)
 
         self.__enter()
@@ -90,35 +97,35 @@ class _Job():
 
     def readlog(self):
         if os.path.exists(self.logfile):
-            with mini_buildd.fopen(self.logfile) as log:
+            with util.fopen(self.logfile) as log:
                 return [line.rstrip() for line in log]
         return []
 
     def savelog(self):
-        with mini_buildd.fopen(self.logfile, "w") as log:
+        with util.fopen(self.logfile, "w") as log:
             for msg in self.log:
                 log.write(msg + "\n")
 
     def __run(self, *args, **kwargs):
         with self._run_lock:
             msg = f"Cronjob '{self.name}'"
-            t0 = mini_buildd.misc.Datetime.now()
+            t0 = util.Datetime.now()
             try:
                 self._action(*args, **kwargs)
                 msg = f"I: {msg}: Successful"
                 LOG.info(msg)
                 return True
             except Exception as e:
-                msg = f"E: {msg}: Failed: {mini_buildd.e2http(e)}"
-                mini_buildd.log_exception(LOG, msg, e)
+                msg = f"E: {msg}: Failed: {util.e2http(e)}"
+                util.log_exception(LOG, msg, e)
                 return False
             finally:
-                msg += f" ({t0}: {(mini_buildd.misc.Datetime.now() - t0).total_seconds()} seconds)"
+                msg += f" ({t0}: {(util.Datetime.now() - t0).total_seconds()} seconds)"
                 self.log.appendleft(msg)
                 self.savelog()
 
     def run(self):
-        """Run now (out of schedule)."""
+        """Run now (out of schedule)"""
         return self.__run(*self._argument, **self._kwargs)
 
     def __action(self, *args, **kwargs):
@@ -126,33 +133,38 @@ class _Job():
         self.__enter()
 
 
-class Tab(mini_buildd.threads.PollerThread):
+class Tab(threads.PollerThread):
     def cronjob_debug(self):
-        """For debugging cron only."""
+        """For debugging cron only"""
         if random.getrandbits(1):
             LOG.debug(f"Running debug cron job for {self}")
         else:
-            raise Exception(f"Failing randomly for {self}")
+            raise util.HTTPBadRequest(f"Failing randomly for {self}")
+
+    @classmethod
+    def cronjob_retry_uploads(cls):
+        """Retry failed (buildresult) uploads"""
+        util.daemon().builder.uploader.retry_failed()
 
     @classmethod
     def cronjob_check(cls):
-        """Check all instances."""
-        mini_buildd.get_daemon().check()
+        """Global check -- explicitly re-check Daemon instance and implicitly all it's dependencies"""
+        util.models().Daemon.Admin.mbd_check(util.models().get_daemon(), force=True)
 
     @classmethod
     def cronjob_expire_builds(cls):
-        """Expire build directories older than 5 days."""
-        mini_buildd.config.ROUTES["builds"].path.expire(datetime.timedelta(days=5))
+        """Expire build directories older than 5 days"""
+        config.ROUTES["builds"].path.expire(datetime.timedelta(days=5))
 
     @classmethod
     def cronjob_expire_events(cls):
-        """Expire event directories older than 1 year."""
-        route = mini_buildd.config.ROUTES["events"]
+        """Expire event directories older than 1 year"""
+        route = config.ROUTES["events"]
         route.path.expire(datetime.timedelta(weeks=1 * 12 * 4))
 
     @classmethod
     def cronjob_snapshots(cls, crontype):
-        """Generate repository snapshots for all stable distributions."""
+        """Generate repository snapshots for all stable distributions"""
         prefix = f"{crontype.name}_"
         keep = {Type.YEARLY: datetime.timedelta(weeks=4 * 12 * 4),  # Keep  4 years
                 Type.MONTHLY: datetime.timedelta(weeks=12 * 4),     # Keep 12 months
@@ -160,7 +172,7 @@ class Tab(mini_buildd.threads.PollerThread):
                 Type.DAILY: datetime.timedelta(days=7),             # Keep 7 days (not in use)
                 Type.MINUTELY: datetime.timedelta(minutes=5)}       # Keep 5 minutes (for TESTING only)
 
-        for r in mini_buildd.models.repository.Repository.mbd_get_active():
+        for r in models.Repository.mbd_get_active():
             for d in r.distributions.all():
                 for s in r.layout.suiteoption_set.filter(experimental=False, migrates_to=None):  # only for "stable" distributions
                     dist_str = r.mbd_get_diststr(d, s)
@@ -183,10 +195,11 @@ class Tab(mini_buildd.threads.PollerThread):
                         LOG.error(f"{crontype.name} expiration code for {dist_str} failed: {e}")
 
     def __init__(self):
-        super().__init__(name="crontab")
+        super().__init__()
         self.scheduler = sched.scheduler()
         self.jobs = []
 
+        self.add(Type.HOURLY, self.cronjob_retry_uploads)
         self.add(Type.WEEKLY, self.cronjob_check)
         self.add(Type.WEEKLY, self.cronjob_expire_builds)
         self.add(Type.WEEKLY, self.cronjob_expire_events)
