@@ -248,6 +248,10 @@ SETUP = {
                                 "extra_options": "X-Remove-From-Component: updates/"
                             },
                         },
+                        "bookworm-backports": {
+                            "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"]],
+                            "origin": "Debian Backports",
+                        },
                     },
                 },
                 "bullseye": {
@@ -265,6 +269,10 @@ SETUP = {
                             "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"]],
                             "origin": "Debian Backports",
                         },
+                        "bullseye-backports-sloppy": {
+                            "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"]],
+                            "origin": "Debian Backports",
+                        },
                     },
                 },
                 "buster": {
@@ -398,7 +406,7 @@ SETUP = {
                     },
                 },
                 "squeeze": {
-                    "urold": "Only works with sbuild < 0.84",
+                    "broken": "Only works with sbuild < 0.84",
 
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["squeeze"]["archive"], APT_KEYS["Debian"]["squeeze"]["release"]],
@@ -437,7 +445,7 @@ SETUP = {
                     },
                 },
                 "lenny": {
-                    "urold": "Cannot build test packages (only dh7 available)",
+                    "broken": "Cannot build test packages (only dh7 available)",
 
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["squeeze"]["archive"], APT_KEYS["Debian"]["lenny"]["release"]],
@@ -492,6 +500,8 @@ SETUP = {
 
             "codename": {
                 "lunar": {  # lunar: 23.04
+                    "broken": "No support in ``debmirror`` yet (May 2023)",
+
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "sources": {
                         "lunar": {},
@@ -716,12 +726,17 @@ SETUP = {
                             },
                         },
                     },
+                    "distribution": {
+                        "options": {
+                            "extra_options": f"{sbuild.SETUP_BLOCKS.name}: apt-setup apt-key-add apt-update ccache eatmydata",
+                        },
+                    },
                     "lintian_options": {
                         "warnfail": ["--fail-on-warnings"],
                     },
                 },
                 "trusty": {  # trusty: 14.04 LTS 2019 ESM 2024
-                    "urold": "``upstart`` install fails in build chroots",
+                    "broken": "``upstart`` install fails in build chroots",
 
                     "apt_keys": [APT_KEYS["Ubuntu"]["2004"], APT_KEYS["Ubuntu"]["2012"]],
                     "sources": {
@@ -815,7 +830,7 @@ def setup_codenames():
 VENDOR_CODENAMES_FUNC = {
     "": lambda origin: [codename for codename in DISTRO_INFO[origin].supported() if codename in setup_codenames()],
     "lts": lambda origin: [codename for codename in DISTRO_INFO[origin].supported() + DISTRO_INFO[origin].mbd_lts() if codename in setup_codenames()],
-    "all": lambda origin: [codename for codename, setup in SETUP["origin"][origin]["codename"].items() if setup.get("urold") is None],
+    "all": lambda origin: [codename for codename, setup in SETUP["origin"][origin]["codename"].items() if setup.get("broken") is None],
 }
 
 
