@@ -10,17 +10,14 @@ import gpg
 import gpg.errors
 import gpg.constants.sig.mode
 
-import mini_buildd
-import mini_buildd.config
-import mini_buildd.misc
-import mini_buildd.call
+from mini_buildd import config, util, call
 
 LOG = logging.getLogger(__name__)
 
 
 class Colons():
     """
-    Provide a colon->name mapping for the gpg script-parsable '--with-colons' output.
+    Provide a colon->name mapping for the gpg script-parsable '--with-colons' output
 
     See /usr/share/doc/gnupg/DETAILS.gz.
     """
@@ -32,7 +29,7 @@ class Colons():
         return f"{self.type}: {self.key_id}: {self.user_id}"
 
     def _get(self, index):
-        return mini_buildd.misc.list_get(self._colons, index, "")
+        return util.list_get(self._colons, index, "")
 
     @property
     def type(self):
@@ -52,16 +49,16 @@ class Colons():
 
     @property
     def user_id(self):
-        """Fingerprint for 'fpr' type."""
+        """Fingerprint for 'fpr' type"""
         return self._get(9)
 
 
-class GpgmeVerifyFailed(mini_buildd.HTTPUnauthorized):
+class GpgmeVerifyFailed(util.HTTPUnauthorized):
     @classmethod
     def sig_info(cls, signature):
-        """Human-readable info combining actual keyid (if subkey, gpgme only provides fpr of subkey) and gpgme reason."""
+        """Human-readable info combining actual keyid (if subkey, gpgme only provides fpr of subkey) and gpgme reason"""
         try:
-            _key, info = mini_buildd.get_daemon().public_key_cache.keyinfo(signature.fpr)
+            _key, info = util.daemon().public_key_cache.keyinfo(signature.fpr)
             return f"{gpg.errors.GpgError(signature.status).code_str}: {info['key']} ({','.join(info['subkeys'])}): {info['user']}"
         except BaseException as e:
             LOG.warning(f"Can't get keyinfo for gpgme signature: {e}")
@@ -80,7 +77,7 @@ class BaseGnuPG():
     @classmethod
     def get_flavor(cls):
         """
-        Ugly-parse GPG binary flavor(=major.minor).
+        Ugly-parse GPG binary flavor(=major.minor)
 
         "1.4" ("classic"), "2.0" ("stable") or "2.1" ("modern") from
         "gpg --version" output (like "gpg (GnuPG) 2.1.14"). Don't fail
@@ -88,7 +85,7 @@ class BaseGnuPG():
 
         """
         try:
-            version_info = mini_buildd.call.Call(["gpg", "--version"]).check().stdout.splitlines()
+            version_info = call.Call(["gpg", "--version"]).check().stdout.splitlines()
             version_line = version_info[0].split(" ")
             return version_line[2][0:3]
         except BaseException as e:
@@ -100,7 +97,7 @@ class BaseGnuPG():
         self.home = home
         self.gpg_cmd = ["gpg",
                         "--homedir", home,
-                        "--display-charset", mini_buildd.config.CHAR_ENCODING,
+                        "--display-charset", config.CHAR_ENCODING,
                         "--batch"]
         self.context = gpg.Context(home_dir=self.home)
 
@@ -111,20 +108,20 @@ class BaseGnuPG():
                             "2.2": "\n%no-protection\n"}
 
         with tempfile.TemporaryFile() as t:
-            t.write(template.encode(mini_buildd.config.CHAR_ENCODING))
-            t.write(flavor_additions.get(self.flavor, "").encode(mini_buildd.config.CHAR_ENCODING))
+            t.write(template.encode(config.CHAR_ENCODING))
+            t.write(flavor_additions.get(self.flavor, "").encode(config.CHAR_ENCODING))
             t.seek(0)
-            mini_buildd.call.Call(self.gpg_cmd + ["--gen-key"], stdin=t).check()
+            call.Call(self.gpg_cmd + ["--gen-key"], stdin=t).check()
 
     def export(self, dest_file, identity=""):
-        with mini_buildd.fopen(dest_file, "w") as f:
-            mini_buildd.call.Call(self.gpg_cmd + ["--export"] + ([identity] if identity else []), stdout=f).check()
+        with util.fopen(dest_file, "w") as f:
+            call.Call(self.gpg_cmd + ["--export"] + ([identity] if identity else []), stdout=f).check()
 
     def get_pub_key(self, identity):
-        return mini_buildd.call.Call(self.gpg_cmd + ["--armor", "--export", identity]).check().stdout
+        return call.Call(self.gpg_cmd + ["--armor", "--export", identity]).check().stdout
 
     def get_colons(self, type_regex, list_arg="--list-public-keys", identity=None):
-        for line in mini_buildd.call.Call(self.gpg_cmd + [list_arg, "--with-colons", "--fixed-list-mode", "--with-fingerprint"] + ([] if identity is None else [identity])).check().stdout.splitlines():
+        for line in call.Call(self.gpg_cmd + [list_arg, "--with-colons", "--fixed-list-mode", "--with-fingerprint"] + ([] if identity is None else [identity])).check().stdout.splitlines():
             colons = Colons(line)
             if re.match(type_regex, colons.type):
                 yield colons
@@ -132,7 +129,7 @@ class BaseGnuPG():
     def get_pub_keys_infos(self):
         infos = []
         info = None
-        for colons in [Colons(line) for line in mini_buildd.call.Call(self.gpg_cmd + ["--list-public-keys", "--with-colons", "--fixed-list-mode", "--with-fingerprint"]).check().stdout.splitlines()]:
+        for colons in [Colons(line) for line in call.Call(self.gpg_cmd + ["--list-public-keys", "--with-colons", "--fixed-list-mode", "--with-fingerprint"]).check().stdout.splitlines()]:
             if colons.type == "pub":  # Start new info section
                 info = {"key": colons.key_id, "created": colons.creation_date, "expires": colons.expiration_date, "fingerprints": [], "subkeys": []}
                 infos.append(info)
@@ -169,9 +166,9 @@ class BaseGnuPG():
 
     def add_pub_key(self, key):
         with tempfile.TemporaryFile() as t:
-            t.write(key.encode(mini_buildd.config.CHAR_ENCODING))
+            t.write(key.encode(config.CHAR_ENCODING))
             t.seek(0)
-            mini_buildd.call.Call(self.gpg_cmd + ["--import"], stdin=t).check()
+            call.Call(self.gpg_cmd + ["--import"], stdin=t).check()
 
     def add_keyring(self, keyring):
         if os.path.exists(keyring):
@@ -181,13 +178,13 @@ class BaseGnuPG():
 
     def verify(self, signature, data=None):
         try:
-            mini_buildd.call.Call(self.gpg_cmd + ["--verify", signature] + ([data] if data else [])).check()
+            call.Call(self.gpg_cmd + ["--verify", signature] + ([data] if data else [])).check()
         except BaseException as e:
-            raise mini_buildd.HTTPBadRequest("GnuPG authorization failed") from e
+            raise util.HTTPBadRequest("GnuPG authorization failed") from e
 
     def gpgme_verify(self, signed_message, signature=None):
         try:
-            return self.context.verify(signed_message.encode(mini_buildd.config.CHAR_ENCODING), signature)
+            return self.context.verify(signed_message.encode(config.CHAR_ENCODING), signature)
         except gpg.errors.GpgError as e:
             raise GpgmeVerifyFailed(f"{e}", e.results.signatures if e.results is not None else None) from e
 
@@ -221,7 +218,7 @@ class BaseGnuPG():
         # (Like 'debsign' from devscripts does: dpkg-source <= squeeze will have problems without the newline)
         unsigned_file = file_name + ".asc"
         shutil.copyfile(file_name, unsigned_file)
-        with mini_buildd.fopen(unsigned_file, "a") as unsigned:
+        with util.fopen(unsigned_file, "a") as unsigned:
             unsigned.write("\n")
 
         # 2nd: Sign the file copy
@@ -232,20 +229,20 @@ class BaseGnuPG():
                 os.remove(signed_file)
 
         # .. attention:: **compat** (:debbug:`849551`): Retrying sign call -- workaround for mystery bug
-        mini_buildd.call.call_with_retry(self.gpg_cmd
-                                         + ["--armor", "--textmode", "--clearsign", "--output", signed_file]
-                                         + (["--local-user", identity] if identity else []) + [unsigned_file],
-                                         retry_max_tries=5,
-                                         retry_sleep=1,
-                                         retry_failed_cleanup=failed_cleanup)
+        call.call_with_retry(self.gpg_cmd
+                             + ["--armor", "--textmode", "--clearsign", "--output", signed_file]
+                             + (["--local-user", identity] if identity else []) + [unsigned_file],
+                             retry_max_tries=5,
+                             retry_sleep=1,
+                             retry_failed_cleanup=failed_cleanup)
 
         # 3rd: Success, move to orig file and cleanup
         os.rename(signed_file, file_name)
         os.remove(unsigned_file)
 
     def gpgme_sign(self, message):
-        signed, _ = self.context.sign(message.encode(mini_buildd.config.CHAR_ENCODING), mode=gpg.constants.sig.mode.CLEAR)
-        return signed.decode(mini_buildd.config.CHAR_ENCODING)
+        signed, _ = self.context.sign(message.encode(config.CHAR_ENCODING), mode=gpg.constants.sig.mode.CLEAR)
+        return signed.decode(config.CHAR_ENCODING)
 
 
 class GnuPG(BaseGnuPG):
@@ -254,7 +251,7 @@ class GnuPG(BaseGnuPG):
         self.pub_key_id = self.get_first_sec_key()
 
     def __init__(self, template, fullname, email):
-        super().__init__(home=mini_buildd.config.ROUTES["home"].path.join(".gnupg"))
+        super().__init__(home=config.ROUTES["home"].path.join(".gnupg"))
         self.template = f"""{template}
 Name-Real: {fullname}
 Name-Email: {email}
@@ -278,14 +275,14 @@ Name-Email: {email}
         return super().get_pub_key("mini-buildd")
 
 
-class TmpGnuPG(BaseGnuPG, mini_buildd.misc.TmpDir):
+class TmpGnuPG(BaseGnuPG, util.TmpDir):
     r"""
-    Temporary GnuPG. Use with contextlib.closing() to guarantee dir is purged afterwards.
+    Temporary GnuPG. Use with contextlib.closing() to guarantee dir is purged afterwards
 
     >>> import contextlib
-    >>> # mini_buildd.config.DEBUG.append("keep")  # Enable 'keep' for debugging only
+    >>> # config.DEBUG.append("keep")  # Enable 'keep' for debugging only
     >>> gnupg_home = tempfile.TemporaryDirectory(prefix="test-home")
-    >>> mini_buildd.config.ROUTES = mini_buildd.config.Routes(gnupg_home.name)
+    >>> config.ROUTES = config.Routes(gnupg_home.name)
     >>> dummy = shutil.copy2("test-data/gpg/secring.gpg", gnupg_home.name)
     >>> dummy = shutil.copy2("test-data/gpg/pubring.gpg", gnupg_home.name)
     >>> gnupg = BaseGnuPG(home=gnupg_home.name)
@@ -299,7 +296,7 @@ class TmpGnuPG(BaseGnuPG, mini_buildd.misc.TmpDir):
     >>> gnupg.get_first_sec_key_fingerprint()  #doctest: +ELLIPSIS
     '4FB13BDD777C046D72D4E7D3AF95FC80FC40A82E'
 
-    >>> with contextlib.closing(mini_buildd.gnupg.TmpGnuPG(tmpdir_options={"prefix": "d17-"})) as tgnupg, tempfile.NamedTemporaryFile(prefix="d0-") as t, tempfile.NamedTemporaryFile(prefix="d1-") as export:
+    >>> with contextlib.closing(TmpGnuPG(tmpdir_options={"prefix": "d17-"})) as tgnupg, tempfile.NamedTemporaryFile(prefix="d0-") as t, tempfile.NamedTemporaryFile(prefix="d1-") as export:
     ...     gnupg.export(export.name)
     ...     dummy = t.write(b"A test file\n")
     ...     t.flush()
@@ -313,14 +310,12 @@ class TmpGnuPG(BaseGnuPG, mini_buildd.misc.TmpDir):
     """
 
     def __init__(self, tmpdir_options=None, **kwargs):
-        mini_buildd.misc.TmpDir.__init__(self, **(tmpdir_options if tmpdir_options else {}))
+        util.TmpDir.__init__(self, **(tmpdir_options if tmpdir_options else {}))
         super().__init__(home=self.tmpdir, **kwargs)
 
 
 class PublicKeyCache(TmpGnuPG):
-    """
-    Public key cache, initially with apt keys installed on the system (usually, from debian-archive-keyring package).
-    """
+    """Public key cache, initially with apt keys installed on the system (usually, from debian-archive-keyring package)"""
 
     KEYSERVER_RECV_TIMEOUT = 5  # seconds
 
@@ -328,18 +323,18 @@ class PublicKeyCache(TmpGnuPG):
         super().__init__(tmpdir_options={"prefix": "gnupg-public-key-cache-"})
         for keyring in glob.glob("/usr/share/keyrings/*-archive-*.gpg"):
             try:
-                mini_buildd.call.Call(self.gpg_cmd + ["--import", keyring]).check()
+                call.Call(self.gpg_cmd + ["--import", keyring]).check()
                 LOG.debug(f"PublicKeyCache: Imported {keyring}")
             except BaseException as e:
                 LOG.warning(f"PublicKeyCache: Failed to import {keyring}: {e}")
 
     @classmethod
     def key2id(cls, key):
-        with contextlib.closing(mini_buildd.gnupg.TmpGnuPG()) as g:
+        with contextlib.closing(TmpGnuPG()) as g:
             g.add_pub_key(key)
             for colons in g.get_colons(type_regex="^pub$"):
                 return colons.key_id
-        raise mini_buildd.HTTPBadRequest("Invalid GnuPG key")
+        raise util.HTTPBadRequest("Invalid GnuPG key")
 
     def keyinfo(self, key_id, key=None):
         pub_keys = self.get_pub_keys()
@@ -350,10 +345,10 @@ class PublicKeyCache(TmpGnuPG):
                 self.add_pub_key(key)
             elif key_id:
                 # Import from keyserver
-                keyserver = mini_buildd.get_daemon().model.gnupg_keyserver
+                keyserver = util.daemon().model.gnupg_keyserver
                 if not keyserver:
-                    raise Exception(f"Key '{key_id}' not in installed archive keys, and no keyserver configured.")
-                mini_buildd.call.call_with_retry(self.gpg_cmd + ["--armor", "--keyserver", keyserver, "--recv-keys", key_id], retry_max_tries=5, retry_sleep=5, timeout=self.KEYSERVER_RECV_TIMEOUT)
+                    raise util.HTTPBadRequest(f"Key '{key_id}' not in installed archive keys, and no keyserver configured")
+                call.call_with_retry(self.gpg_cmd + ["--armor", "--keyserver", keyserver, "--recv-keys", key_id], retry_max_tries=5, retry_sleep=5, timeout=self.KEYSERVER_RECV_TIMEOUT)
                 LOG.debug(f"PublicKeyCache: '{key_id}' imported from key server '{keyserver}'.")
 
             # Update pub keys
